Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(347)

Unified Diff: third_party/WebKit/Source/core/html/HTMLEmbedElementTest.cpp

Issue 2737713002: Rename updateWidgets to updatePlugins (Closed)
Patch Set: Rename updateWidgets to updatePlugins Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/html/HTMLEmbedElementTest.cpp
diff --git a/third_party/WebKit/Source/core/html/HTMLEmbedElementTest.cpp b/third_party/WebKit/Source/core/html/HTMLEmbedElementTest.cpp
index b03c727b4843bc9eee3e77cc1c2c7dfbc337e9a4..fd22ac4222e0ecfbb67667db8a15371474b324f9 100644
--- a/third_party/WebKit/Source/core/html/HTMLEmbedElementTest.cpp
+++ b/third_party/WebKit/Source/core/html/HTMLEmbedElementTest.cpp
@@ -58,9 +58,9 @@ TEST_F(HTMLEmbedElementTest, FallbackState) {
ASSERT_TRUE(isHTMLObjectElement(objectElement));
HTMLObjectElement* object = toHTMLObjectElement(objectElement);
// At this moment updateWidget() function is not called, so
// useFallbackContent() will return false.
// But the element will likely to use fallback content after updateWidget().
EXPECT_TRUE(object->hasFallbackContent());
EXPECT_FALSE(object->useFallbackContent());
EXPECT_TRUE(object->willUseFallbackContentAtLayout());
@@ -77,7 +77,7 @@ TEST_F(HTMLEmbedElementTest, FallbackState) {
ComputedStyle::initialStyle()));
// This call will update fallback state of the object.
- object->updateWidget();
+ object->updatePlugin();
EXPECT_TRUE(object->hasFallbackContent());
EXPECT_TRUE(object->useFallbackContent());
« no previous file with comments | « third_party/WebKit/Source/core/html/HTMLEmbedElement.cpp ('k') | third_party/WebKit/Source/core/html/HTMLObjectElement.h » ('j') | no next file with comments »
@@ -58,9 +58,9 @@ TEST_F(HTMLEmbedElementTest, FallbackState) {
ASSERT_TRUE(isHTMLObjectElement(objectElement));
HTMLObjectElement* object = toHTMLObjectElement(objectElement);
- // At this moment updateWidget() function is not called, so
+ // At this moment updatePlugin() function is not called, so
// useFallbackContent() will return false.
@@ -58,9 +58,9 @@ TEST_F(HTMLEmbedElementTest, FallbackState) {
// useFallbackContent() will return false.
- // But the element will likely to use fallback content after updateWidget().
+ // But the element will likely to use fallback content after updatePlugin().
EXPECT_TRUE(object->hasFallbackContent());
EXPECT_FALSE(object->useFallbackContent());

Powered by Google App Engine
This is Rietveld 408576698